ENUsername class

English username

Inheritance

Constructors

ENUsername({String? surName, String? givenName})

Properties

fullname String
fullname
no setteroverride
givenName String?
given name
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surName String?
surname
finalinherited
topGivenNames List<String>
top given names
no setteroverride
topSurNames List<String>
top surnames
no setteroverride

Methods

getFullnames({int count = 0}) List<String>
inherited
getGivenName() String
get random given name. if specified given name,then given name fixed. or else use top random given name
inherited
getSurName() String
get random surname. if specified surname,then surname fixed. or else use top random surname
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
splitCommaString(String input) List<String>
tool: split string with comma
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited